@@ -500,14 +500,19 @@ func (ctrl *Controller) syncGeneratedMachineConfig(pool *mcfgv1.MachineConfigPoo
 		return err
 	}
 
+	newPool := pool.DeepCopy()
+	newPool.Spec.Configuration.Source = source
+
 	if pool.Spec.Configuration.Name == generated.Name {
 		_, _, err = resourceapply.ApplyMachineConfig(ctrl.client.MachineconfigurationV1(), generated)
+		if err != nil {
+			return err
+		}
+		_, err = ctrl.client.MachineconfigurationV1().MachineConfigPools().Update(context.TODO(), newPool, metav1.UpdateOptions{})
 		return err
 	}
 
-	newPool := pool.DeepCopy()
 	newPool.Spec.Configuration.Name = generated.Name
-	newPool.Spec.Configuration.Source = source
 	// TODO(walters) Use subresource or JSON patch, but the latter isn't supported by the unit test mocks
 	pool, err = ctrl.client.MachineconfigurationV1().MachineConfigPools().Update(context.TODO(), newPool, metav1.UpdateOptions{})
 	if err != nil {
@@ -530,6 +535,7 @@ func generateRenderedMachineConfig(pool *mcfgv1.MachineConfigPool, configs []*mc
 			return nil, err
 		}
 	}
+
 	merged, err := ctrlcommon.MergeMachineConfigs(configs, cconfig.Spec.OSImageURL)
 	if err != nil {
 		return nil, err
@@ -569,8 +575,15 @@ func RunBootstrap(pools []*mcfgv1.MachineConfigPool, configs []*mcfgv1.MachineCo
 			return nil, nil, err
 		}
 
+		source := []corev1.ObjectReference{}
+		for _, cfg := range configs {
+			source = append(source, corev1.ObjectReference{Kind: machineconfigKind.Kind, Name: cfg.GetName(), APIVersion: machineconfigKind.GroupVersion().String()})
+		}
+
 		pool.Spec.Configuration.Name = generated.Name
+		pool.Spec.Configuration.Source = source
 		pool.Status.Configuration.Name = generated.Name
+		pool.Status.Configuration.Source = source
 		opools = append(opools, pool)
 		oconfigs = append(oconfigs, generated)
 	}
