@@ -9,10 +9,12 @@ import (
 	"path/filepath"
 	"testing"
 
-	ign "github.com/coreos/ignition/config/v2_2"
-	igntypes "github.com/coreos/ignition/config/v2_2/types"
-	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
+	ign3types "github.com/coreos/ignition/v2/config/v3_1/types"
+	configv1 "github.com/openshift/api/config/v1"
 	"k8s.io/client-go/kubernetes/scheme"
+
+	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
+	ctrlcommon "github.com/openshift/machine-config-operator/pkg/controller/common"
 )
 
 func TestMain(m *testing.M) {
@@ -24,28 +26,28 @@ func TestCloudProvider(t *testing.T) {
 	dummyTemplate := []byte(`{{cloudProvider .}}`)
 
 	cases := []struct {
-		platform string
+		platform configv1.PlatformType
 		res      string
 	}{{
-		platform: "aws",
+		platform: configv1.AWSPlatformType,
 		res:      "aws",
 	}, {
-		platform: "openstack",
+		platform: configv1.OpenStackPlatformType,
 		res:      "openstack",
 	}, {
-		platform: "baremetal",
+		platform: configv1.BareMetalPlatformType,
 		res:      "",
 	}, {
-		platform: "gcp",
+		platform: configv1.GCPPlatformType,
 		res:      "gce",
 	}, {
-		platform: "libvirt",
+		platform: configv1.LibvirtPlatformType,
 		res:      "",
 	}, {
-		platform: "none",
+		platform: configv1.NonePlatformType,
 		res:      "",
 	}, {
-		platform: "vsphere",
+		platform: configv1.VSpherePlatformType,
 		res:      "vsphere",
 	}}
 	for idx, c := range cases {
@@ -53,7 +55,13 @@ func TestCloudProvider(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			config := &mcfgv1.ControllerConfig{
 				Spec: mcfgv1.ControllerConfigSpec{
-					Platform: c.platform,
+					Infra: &configv1.Infrastructure{
+						Status: configv1.InfrastructureStatus{
+							PlatformStatus: &configv1.PlatformStatus{
+								Type: c.platform,
+							},
+						},
+					},
 				},
 			}
 			got, err := renderTemplate(RenderConfig{&config.Spec, `{"dummy":"dummy"}`}, name, dummyTemplate)
@@ -72,37 +80,37 @@ func TestCloudConfigFlag(t *testing.T) {
 	dummyTemplate := []byte(`{{cloudConfigFlag .}}`)
 
 	cases := []struct {
-		platform string
+		platform configv1.PlatformType
 		content  string
 		res      string
 	}{{
-		platform: "aws",
+		platform: configv1.AWSPlatformType,
 		content:  "",
 		res:      "",
 	}, {
-		platform: "azure",
+		platform: configv1.AzurePlatformType,
 		content:  "",
 		res:      "",
 	}, {
-		platform: "libvirt",
+		platform: configv1.LibvirtPlatformType,
 		content:  "",
 		res:      "",
 	}, {
-		platform: "aws",
+		platform: configv1.AWSPlatformType,
 		content: `
 [dummy-config]
     option = a
 `,
 		res: "--cloud-config=/etc/kubernetes/cloud.conf",
 	}, {
-		platform: "libvirt",
+		platform: configv1.LibvirtPlatformType,
 		content: `
 [dummy-config]
     option = a
 `,
 		res: "",
 	}, {
-		platform: "azure",
+		platform: configv1.AzurePlatformType,
 		content: `
 [dummy-config]
     option = a
@@ -114,7 +122,13 @@ func TestCloudConfigFlag(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			config := &mcfgv1.ControllerConfig{
 				Spec: mcfgv1.ControllerConfigSpec{
-					Platform:            c.platform,
+					Infra: &configv1.Infrastructure{
+						Status: configv1.InfrastructureStatus{
+							PlatformStatus: &configv1.PlatformStatus{
+								Type: c.platform,
+							},
+						},
+					},
 					CloudProviderConfig: c.content,
 				},
 			}
@@ -130,71 +144,6 @@ func TestCloudConfigFlag(t *testing.T) {
 	}
 }
 
-func TestEtcdPeerCertDNSNames(t *testing.T) {
-	dummyTemplate := []byte(`{{etcdPeerCertDNSNames .}}`)
-
-	cases := []struct {
-		etcdDiscoveryDomain string
-
-		url string
-		err bool
-	}{{
-		etcdDiscoveryDomain: "",
-		url:                 "",
-		err:                 true,
-	}, {
-		etcdDiscoveryDomain: "my-test-cluster.tt.testing",
-		url:                 "${ETCD_DNS_NAME},my-test-cluster.tt.testing",
-		err:                 false,
-	}}
-	for idx, c := range cases {
-		name := fmt.Sprintf("case #%d", idx)
-		t.Run(name, func(t *testing.T) {
-			config := &mcfgv1.ControllerConfig{
-				Spec: mcfgv1.ControllerConfigSpec{
-					EtcdDiscoveryDomain: c.etcdDiscoveryDomain,
-				},
-			}
-			got, err := renderTemplate(RenderConfig{&config.Spec, `{"dummy":"dummy"}`}, name, dummyTemplate)
-			if err != nil && !c.err {
-				t.Fatalf("expected nil error %v", err)
-			}
-
-			if string(got) != c.url {
-				t.Fatalf("mismatch got: %s want: %s", got, c.url)
-			}
-		})
-	}
-}
-
-func TestEtcdServerCertDNSNames(t *testing.T) {
-	dummyTemplate := []byte(`{{etcdServerCertDNSNames .}}`)
-
-	cases := []struct {
-		url string
-		err bool
-	}{{
-		url: "localhost,etcd.kube-system.svc,etcd.kube-system.svc.cluster.local,etcd.openshift-etcd.svc,etcd.openshift-etcd.svc.cluster.local,${ETCD_WILDCARD_DNS_NAME}",
-		err: false,
-	}}
-	for idx, c := range cases {
-		name := fmt.Sprintf("case #%d", idx)
-		t.Run(name, func(t *testing.T) {
-			config := &mcfgv1.ControllerConfig{
-				Spec: mcfgv1.ControllerConfigSpec{},
-			}
-			got, err := renderTemplate(RenderConfig{&config.Spec, `{"dummy":"dummy"}`}, name, dummyTemplate)
-			if err != nil && !c.err {
-				t.Fatalf("expected nil error %v", err)
-			}
-
-			if string(got) != c.url {
-				t.Fatalf("mismatch got: %s want: %s", got, c.url)
-			}
-		})
-	}
-}
-
 func TestSkipMissing(t *testing.T) {
 	dummyTemplate := `{{skip "%s"}}`
 
@@ -218,11 +167,8 @@ func TestSkipMissing(t *testing.T) {
 		key: "index",
 		err: false,
 		res: "{{.index}}",
-	}, {
-		key: "etcd_index",
-		err: false,
-		res: "{{.etcd_index}}",
-	}}
+	},
+	}
 
 	for idx, c := range cases {
 		name := fmt.Sprintf("case #%d", idx)
@@ -240,10 +186,7 @@ func TestSkipMissing(t *testing.T) {
 	}
 }
 
-const (
-	templateDir = "../../../templates"
-	resultDir   = "./test_data/templates"
-)
+const templateDir = "../../../templates"
 
 var (
 	configs = map[string]string{
@@ -274,14 +217,14 @@ func TestInvalidPlatform(t *testing.T) {
 	}
 
 	// we must treat unrecognized constants as "none"
-	controllerConfig.Spec.Platform = "_bad_"
+	controllerConfig.Spec.Infra.Status.PlatformStatus.Type = "_bad_"
 	_, err = generateTemplateMachineConfigs(&RenderConfig{&controllerConfig.Spec, `{"dummy":"dummy"}`}, templateDir)
 	if err != nil {
 		t.Errorf("expect nil error, got: %v", err)
 	}
 
 	// explicitly blocked
-	controllerConfig.Spec.Platform = "_base"
+	controllerConfig.Spec.Infra.Status.PlatformStatus.Type = "_base"
 	_, err = generateTemplateMachineConfigs(&RenderConfig{&controllerConfig.Spec, `{"dummy":"dummy"}`}, templateDir)
 	expectErr(err, "failed to create MachineConfig for role master: platform _base unsupported")
 }
@@ -313,7 +256,7 @@ func TestGenerateMachineConfigs(t *testing.T) {
 				t.Fatal("role label missing")
 			}
 
-			ign, _, err := ign.Parse(cfg.Spec.Config.Raw)
+			ign, err := ctrlcommon.ParseAndConvertConfig(cfg.Spec.Config.Raw)
 			if err != nil {
 				t.Errorf("Failed to parse Ignition config")
 			}
@@ -340,13 +283,13 @@ func TestGenerateMachineConfigs(t *testing.T) {
 			t.Errorf("Failed to find pull secret for master")
 		}
 		if !foundKubeletUnitMaster {
-			t.Errorf("Failed to find kubelet unit")
+			t.Errorf("Failed to find kubelet unit for master")
 		}
 		if !foundPullSecretWorker {
-			t.Errorf("Failed to find pull secret")
+			t.Errorf("Failed to find pull secret for worker")
 		}
 		if !foundKubeletUnitWorker {
-			t.Errorf("Failed to find kubelet unit")
+			t.Errorf("Failed to find kubelet unit for worker")
 		}
 	}
 }
@@ -367,7 +310,7 @@ func controllerConfigFromFile(path string) (*mcfgv1.ControllerConfig, error) {
 	return cc, nil
 }
 
-func findIgnFile(files []igntypes.File, path string, t *testing.T) bool {
+func findIgnFile(files []ign3types.File, path string, t *testing.T) bool {
 	for _, f := range files {
 		if f.Path == path {
 			return true
@@ -376,7 +319,7 @@ func findIgnFile(files []igntypes.File, path string, t *testing.T) bool {
 	return false
 }
 
-func findIgnUnit(units []igntypes.Unit, name string, t *testing.T) bool {
+func findIgnUnit(units []ign3types.Unit, name string, t *testing.T) bool {
 	for _, u := range units {
 		if u.Name == name {
 			return true
