@@ -2,12 +2,16 @@ package e2e_test
 
 import (
 	"context"
+	"encoding/json"
 	"testing"
 	"time"
 
 	"github.com/golang/glog"
+	ctrlcommon "github.com/openshift/machine-config-operator/pkg/controller/common"
 	"github.com/openshift/machine-config-operator/pkg/controller/node"
 	"github.com/openshift/machine-config-operator/test/e2e/framework"
+	"github.com/stretchr/testify/require"
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 )
@@ -69,13 +73,13 @@ func checkMasterNodesSchedulability(cs *framework.ClientSet, masterSchedulable b
 	}
 	if masterSchedulable {
 		for _, masterNode := range masterNodes.Items {
-			if !node.CheckMasterIsAlreadySchedulable(&masterNode) {
+			if !CheckMasterIsAlreadySchedulable(&masterNode) {
 				return false
 			}
 		}
 	} else {
 		for _, masterNode := range masterNodes.Items {
-			if node.CheckMasterIsAlreadySchedulable(&masterNode) {
+			if CheckMasterIsAlreadySchedulable(&masterNode) {
 				return false
 			}
 		}
@@ -83,6 +87,19 @@ func checkMasterNodesSchedulability(cs *framework.ClientSet, masterSchedulable b
 	return true
 }
 
+// CheckMasterIsAlreadySchedulable checks if the given node has a worker label and doesn't have NoSchedule master
+// taint
+func CheckMasterIsAlreadySchedulable(master *corev1.Node) bool {
+	_, hasWorkerLabel := master.Labels[node.WorkerLabel]
+	hasMasterTaint := false
+	for _, taint := range master.Spec.Taints {
+		if taint.Key == ctrlcommon.MasterLabel && taint.Effect == corev1.TaintEffectNoSchedule {
+			hasMasterTaint = true
+		}
+	}
+	return hasWorkerLabel && !hasMasterTaint
+}
+
 func waitForAllMastersUpdate(cs *framework.ClientSet, mastersSchedulable bool) error {
 	return wait.PollImmediate(1*time.Second, 5*time.Minute, func() (bool, error) {
 		if !checkMasterNodesSchedulability(cs, mastersSchedulable) {
@@ -92,3 +109,26 @@ func waitForAllMastersUpdate(cs *framework.ClientSet, mastersSchedulable bool) e
 		return true, nil
 	})
 }
+
+func TestClusterOperatorStatusExtension(t *testing.T) {
+	cs := framework.NewClientSet("")
+	co, err := cs.ClusterOperators().Get(context.TODO(), "machine-config", metav1.GetOptions{})
+	require.Nil(t, err)
+	ext := map[string]string{
+		"test": "extension",
+	}
+	rawExt, err := json.Marshal(ext)
+	require.Nil(t, err)
+	co.Status.Extension.Raw = rawExt
+	_, err = cs.ClusterOperators().UpdateStatus(context.TODO(), co, metav1.UpdateOptions{})
+	require.Nil(t, err)
+	co, err = cs.ClusterOperators().Get(context.TODO(), "machine-config", metav1.GetOptions{})
+	require.Nil(t, err)
+	require.NotNil(t, co.Status.Extension)
+	coExt := map[string]string{}
+	err = json.Unmarshal(co.Status.Extension.Raw, &coExt)
+	require.Nil(t, err)
+	v, ok := coExt["test"]
+	require.True(t, ok)
+	require.Equal(t, "extension", v)
+}
